==> haskell-mono-traversable-instances-0.1.1.0-324-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-LIMM4QOD416HnqJ41tUm7A
key:                  mono-traversable-instances-0.1.1.0-LIMM4QOD416HnqJ41tUm7A
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  339f8b17945c381f57e0c5ce2e9357fc
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-LIMM4QOD416HnqJ41tUm7A
depends:
    base-4.17.2.1 comonad-5.0.9-FYFp3piv5hy78OOCKg42iq containers-0.6.7
    dlist-1.0-3IsW2ghxYJNLBlqCManDLX
    dlist-instances-0.1.1.1-4K3FYTSTMSK8uyD1Y7TKt9
    mono-traversable-1.0.21.0-CpA5hRjl7g5CjbzhTzBx17
    semigroupoids-6.0.1-8sKf1o1a2c6K4GAi4qlWGt transformers-0.5.6.2
    vector-instances-3.4.3-6fC6k4LoGM9FIy36MLkDdo

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-325-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-7wLrengyWhPKM9l4zKupiq
key:                  mono-traversable-instances-0.1.1.0-7wLrengyWhPKM9l4zKupiq
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  ba45b702d54397c3092577fadd636978
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-7wLrengyWhPKM9l4zKupiq
depends:
    base-4.17.2.1 comonad-5.0.9-Er3eq4gTywwJing4fQLPZd containers-0.6.7
    dlist-1.0-IJrTDexief3J1GR3vYsW3H
    dlist-instances-0.1.1.1-1A5Jvrueg9j8U3NBjpP2Yq
    mono-traversable-1.0.21.0-8wGv7rI3e9Z933UAlQh2IM
    semigroupoids-6.0.1-KXp0LYmddte6kFAiCW0XGO transformers-0.5.6.2
    vector-instances-3.4.3-6Zpfy9qFDYrLJ37BEwDywZ

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
